﻿using MindFusion.Diagramming;
using MindFusion.Drawing;

using Behavior = MindFusion.Diagramming.Behavior;


namespace StockShapes;

public partial class MainPage : ContentPage
{
	public MainPage()
	{
		InitializeComponent();

		Diagram diagram = diagramView.Diagram;
		diagram.SelectAfterCreate = false;
		diagramView.Behavior = Behavior.PanAndModify;

		// set colors
		diagram.BackBrush = new SolidBrush(Colors.Azure);
		diagram.DiagramStyle.ShadowBrush = new SolidBrush(
			Color.FromRgba(0, 0, 0, 20));
		diagram.DiagramStyle.NodeEffects.Add(new GlassEffect());
		diagram.DiagramStyle.FontFamily = "Tahoma";
		diagram.DiagramStyle.FontSize = 3;

		int i = 0;
		int hsize = 17;
		int vsize = 19;
		int perLine = NodesPerLine();

		// enum all predefined shapes
		foreach (Shape shape in Shape.Shapes)
		{
			// skip arrowheads
			if (shape.Outline.Length == 0 ||
				shape == ArrowHeads.RevWithCirc ||
				shape == ArrowHeads.DoubleArrow)
				continue;

			// create a node showing this shape
			ShapeNode box = diagram.Factory.CreateShapeNode(
				(i % perLine) * (hsize + 5) + 2,
				(i / perLine) * (vsize + 15) + 4,
				hsize, vsize, shape);

			box.Pen = new Pen(Colors.Black, 0);

			var label = diagram.Factory.CreateShapeNode(
				(i % perLine) * (hsize + 5),
				(i / perLine) * (vsize + 15) + vsize + 4,
				hsize + 4, 8, Shapes.Rectangle);
			label.Text = shape.Id;
			label.Locked = true;
			label.Transparent = true;

			label.AttachToNode(box, AttachToNode.BottomRight);

			i = i + 1;
		}

		diagram.ResizeToFitItems(4, true);
	}

	protected override void OnSizeAllocated(double width, double height)
	{
		base.OnSizeAllocated(width, height);
		Zoom();
	}

	protected override Size ArrangeOverride(Rect bounds)
    {
        var size = base.ArrangeOverride(bounds);
		Zoom();
		return size;
    }

	void Zoom()
	{
		if (diagramView.Viewport.Width > 0 && !zoomed)
		{
			diagramView.ZoomFactor = 100.0 *
				diagramView.Viewport.Width /
				diagramView.Diagram.Bounds.Width - 5;

			zoomed = true;
		}
	}

	int NodesPerLine()
	{
		if (DeviceInfo.Current.Idiom == DeviceIdiom.Desktop)
			return 9;
		if (DeviceInfo.Current.Idiom == DeviceIdiom.Tablet)
			return 6;
		if (DeviceInfo.Current.Idiom == DeviceIdiom.Phone)
			return 3;

		return 9;
	}

	bool zoomed = false;
}
